==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/TaskWorkflow.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) A GitHub workflow for common build tasks within a project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.772Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.TaskWorkflow")
public class TaskWorkflow extends io.github.cdklabs.projen.github.GithubWorkflow {

    protected TaskWorkflow(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TaskWorkflow(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TaskWorkflow(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.TaskWorkflowOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getJobId() {
        return software.amazon.jsii.Kernel.get(this, "jobId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.TaskWorkflow}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.TaskWorkflow> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private final io.github.cdklabs.projen.github.TaskWorkflowOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
            this.options = new io.github.cdklabs.projen.github.TaskWorkflowOptions.Builder();
        }

        /**
         * (experimental) The workflow name.
         * <p>
         * @return {@code this}
         * @param name The workflow name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.options.name(name);
            return this;
        }

        /**
         * (experimental) Permissions for the build job.
         * <p>
         * @return {@code this}
         * @param permissions Permissions for the build job. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder permissions(final io.github.cdklabs.projen.github.workflows.JobPermissions permissions) {
            this.options.permissions(permissions);
            return this;
        }

        /**
         * (experimental) The main task to be executed.
         * <p>
         * @return {@code this}
         * @param task The main task to be executed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder task(final io.github.cdklabs.projen.Task task) {
            this.options.task(task);
            return this;
        }

        /**
         * (experimental) A directory name which contains artifacts to be uploaded (e.g. `dist`). If this is set, the contents of this directory will be uploaded as an artifact at the end of the workflow run, even if other steps fail.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param artifactsDirectory A directory name which contains artifacts to be uploaded (e.g. `dist`). If this is set, the contents of this directory will be uploaded as an artifact at the end of the workflow run, even if other steps fail. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactsDirectory(final java.lang.String artifactsDirectory) {
            this.options.artifactsDirectory(artifactsDirectory);
            return this;
        }

        /**
         * (experimental) Override for the `with` property of the source code checkout step.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param checkoutWith Override for the `with` property of the source code checkout step. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder checkoutWith(final java.util.Map<java.lang.String, ? extends java.lang.Object> checkoutWith) {
            this.options.checkoutWith(checkoutWith);
            return this;
        }

        /**
         * (experimental) Adds an 'if' condition to the workflow.
         * <p>
         * @return {@code this}
         * @param condition Adds an 'if' condition to the workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder condition(final java.lang.String condition) {
            this.options.condition(condition);
            return this;
        }

        /**
         * Default: - default image
         * <p>
         * @return {@code this}
         * @param container This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder container(final io.github.cdklabs.projen.github.workflows.ContainerOptions container) {
            this.options.container(container);
            return this;
        }

        /**
         * (experimental) Workflow environment variables.
         * <p>
         * Default: {}
         * <p>
         * @return {@code this}
         * @param env Workflow environment variables. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder env(final java.util.Map<java.lang.String, java.lang.String> env) {
            this.options.env(env);
            return this;
        }

        /**
         * (experimental) The git identity to use in this workflow.
         * <p>
         * @return {@code this}
         * @param gitIdentity The git identity to use in this workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder gitIdentity(final io.github.cdklabs.projen.github.GitIdentity gitIdentity) {
            this.options.gitIdentity(gitIdentity);
            return this;
        }

        /**
         * (experimental) The primary job id.
         * <p>
         * Default: "build"
         * <p>
         * @return {@code this}
         * @param jobId The primary job id. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder jobId(final java.lang.String jobId) {
            this.options.jobId(jobId);
            return this;
        }

        /**
         * (experimental) Mapping of job output names to values/expressions.
         * <p>
         * Default: {}
         * <p>
         * @return {@code this}
         * @param outputs Mapping of job output names to values/expressions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder outputs(final java.util.Map<java.lang.String, ? extends io.github.cdklabs.projen.github.workflows.JobStepOutput> outputs) {
            this.options.outputs(outputs);
            return this;
        }

        /**
         * (experimental) Actions to run after the main build step.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param postBuildSteps Actions to run after the main build step. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder postBuildSteps(final java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> postBuildSteps) {
            this.options.postBuildSteps(postBuildSteps);
            return this;
        }

        /**
         * (experimental) Steps to run before the main build step.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param preBuildSteps Steps to run before the main build step. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder preBuildSteps(final java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> preBuildSteps) {
            this.options.preBuildSteps(preBuildSteps);
            return this;
        }

        /**
         * (experimental) Initial steps to run before the source code checkout.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param preCheckoutSteps Initial steps to run before the source code checkout. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder preCheckoutSteps(final java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> preCheckoutSteps) {
            this.options.preCheckoutSteps(preCheckoutSteps);
            return this;
        }

        /**
         * (experimental) Github Runner selection labels.
         * <p>
         * Default: ["ubuntu-latest"]
         * <p>
         * @return {@code this}
         * @param runsOn Github Runner selection labels. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(final java.util.List<java.lang.String> runsOn) {
            this.options.runsOn(runsOn);
            return this;
        }

        /**
         * (experimental) The triggers for the workflow.
         * <p>
         * Default: - by default workflows can only be triggered by manually.
         * <p>
         * @return {@code this}
         * @param triggers The triggers for the workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder triggers(final io.github.cdklabs.projen.github.workflows.Triggers triggers) {
            this.options.triggers(triggers);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.github.TaskWorkflow}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.TaskWorkflow build() {
            return new io.github.cdklabs.projen.github.TaskWorkflow(
                this.github,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/TaskWorkflow.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) A GitHub workflow for common build tasks within a project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.438Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.TaskWorkflow")
public class TaskWorkflow extends io.github.cdklabs.projen.github.GithubWorkflow {

    protected TaskWorkflow(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TaskWorkflow(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TaskWorkflow(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.TaskWorkflowOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getJobId() {
        return software.amazon.jsii.Kernel.get(this, "jobId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getArtifactsDirectory() {
        return software.amazon.jsii.Kernel.get(this, "artifactsDirectory", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.TaskWorkflow}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.TaskWorkflow> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private final io.github.cdklabs.projen.github.TaskWorkflowOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
            this.options = new io.github.cdklabs.projen.github.TaskWorkflowOptions.Builder();
        }

        /**
         * (experimental) Permissions for the build job.
         * <p>
         * @return {@code this}
         * @param permissions Permissions for the build job. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder permissions(final io.github.cdklabs.projen.github.workflows.JobPermissions permissions) {
            this.options.permissions(permissions);
            return this;
        }

        /**
         * (experimental) A directory name which contains artifacts to be uploaded (e.g. <code>dist</code>). If this is set, the contents of this directory will be uploaded as an artifact at the end of the workflow run, even if other steps fail.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param artifactsDirectory A directory name which contains artifacts to be uploaded (e.g. <code>dist</code>). If this is set, the contents of this directory will be uploaded as an artifact at the end of the workflow run, even if other steps fail. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactsDirectory(final java.lang.String artifactsDirectory) {
            this.options.artifactsDirectory(artifactsDirectory);
            return this;
        }

        /**
         * (experimental) Override for the <code>with</code> property of the source code checkout step.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param checkoutWith Override for the <code>with</code> property of the source code checkout step. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder checkoutWith(final io.github.cdklabs.projen.github.CheckoutWith checkoutWith) {
            this.options.checkoutWith(checkoutWith);
            return this;
        }

        /**
         * (experimental) Adds an 'if' condition to the workflow.
         * <p>
         * @return {@code this}
         * @param condition Adds an 'if' condition to the workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder condition(final java.lang.String condition) {
            this.options.condition(condition);
            return this;
        }

        /**
         * Default: - default image
         * <p>
         * @return {@code this}
         * @param container This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder container(final io.github.cdklabs.projen.github.workflows.ContainerOptions container) {
            this.options.container(container);
            return this;
        }

        /**
         * (experimental) Whether to download files from Git LFS for this workflow.
         * <p>
         * Default: - Use the setting on the corresponding GitHub project
         * <p>
         * @return {@code this}
         * @param downloadLfs Whether to download files from Git LFS for this workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder downloadLfs(final java.lang.Boolean downloadLfs) {
            this.options.downloadLfs(downloadLfs);
            return this;
        }

        /**
         * (experimental) Workflow environment variables.
         * <p>
         * Default: {}
         * <p>
         * @return {@code this}
         * @param env Workflow environment variables. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder env(final java.util.Map<java.lang.String, java.lang.String> env) {
            this.options.env(env);
            return this;
        }

        /**
         * (experimental) The git identity to use in this workflow.
         * <p>
         * @return {@code this}
         * @param gitIdentity The git identity to use in this workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder gitIdentity(final io.github.cdklabs.projen.github.GitIdentity gitIdentity) {
            this.options.gitIdentity(gitIdentity);
            return this;
        }

        /**
         * (experimental) Default settings for all steps in the TaskWorkflow Job.
         * <p>
         * @return {@code this}
         * @param jobDefaults Default settings for all steps in the TaskWorkflow Job. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder jobDefaults(final io.github.cdklabs.projen.github.workflows.JobDefaults jobDefaults) {
            this.options.jobDefaults(jobDefaults);
            return this;
        }

        /**
         * (experimental) Mapping of job output names to values/expressions.
         * <p>
         * Default: {}
         * <p>
         * @return {@code this}
         * @param outputs Mapping of job output names to values/expressions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder outputs(final java.util.Map<java.lang.String, ? extends io.github.cdklabs.projen.github.workflows.JobStepOutput> outputs) {
            this.options.outputs(outputs);
            return this;
        }

        /**
         * (experimental) Actions to run after the main build step.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param postBuildSteps Actions to run after the main build step. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder postBuildSteps(final java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> postBuildSteps) {
            this.options.postBuildSteps(postBuildSteps);
            return this;
        }

        /**
         * (experimental) Steps to run before the main build step.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param preBuildSteps Steps to run before the main build step. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder preBuildSteps(final java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> preBuildSteps) {
            this.options.preBuildSteps(preBuildSteps);
            return this;
        }

        /**
         * (experimental) Initial steps to run before the source code checkout.
         * <p>
         * Default: - not set
         * <p>
         * @return {@code this}
         * @param preCheckoutSteps Initial steps to run before the source code checkout. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder preCheckoutSteps(final java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> preCheckoutSteps) {
            this.options.preCheckoutSteps(preCheckoutSteps);
            return this;
        }

        /**
         * (experimental) Github Runner selection labels.
         * <p>
         * Default: ["ubuntu-latest"]
         * <p>
         * @return {@code this}
         * @param runsOn Github Runner selection labels. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(final java.util.List<java.lang.String> runsOn) {
            this.options.runsOn(runsOn);
            return this;
        }

        /**
         * (experimental) Github Runner Group selection options.
         * <p>
         * @return {@code this}
         * @param runsOnGroup Github Runner Group selection options. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOnGroup(final io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup) {
            this.options.runsOnGroup(runsOnGroup);
            return this;
        }

        /**
         * (experimental) The workflow name.
         * <p>
         * @return {@code this}
         * @param name The workflow name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.options.name(name);
            return this;
        }

        /**
         * (experimental) The main task to be executed.
         * <p>
         * @return {@code this}
         * @param task The main task to be executed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder task(final io.github.cdklabs.projen.Task task) {
            this.options.task(task);
            return this;
        }

        /**
         * (experimental) The primary job id.
         * <p>
         * Default: "build"
         * <p>
         * @return {@code this}
         * @param jobId The primary job id. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder jobId(final java.lang.String jobId) {
            this.options.jobId(jobId);
            return this;
        }

        /**
         * (experimental) The triggers for the workflow.
         * <p>
         * Default: - by default workflows can only be triggered by manually.
         * <p>
         * @return {@code this}
         * @param triggers The triggers for the workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder triggers(final io.github.cdklabs.projen.github.workflows.Triggers triggers) {
            this.options.triggers(triggers);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.github.TaskWorkflow}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.TaskWorkflow build() {
            return new io.github.cdklabs.projen.github.TaskWorkflow(
                this.github,
                this.options.build()
            );
        }
    }
}
